import { Button, Form, Input, Select } from "antd"
import "../index.css"
import { useState } from "react"
import form from "antd/es/form"
import { Avatar } from "antd" // 新增Avatar组件
function App() {
  const [status, setStatus] = useState("未提交")
  const [loading, setLoading] = useState(false)
  const [form] = Form.useForm()
  const handleReset = () => {
    setStatus("未提交")
    form.resetFields()
  }
  return (
    <div className="min-h-screen flex bg-slate-900"> {/* 改为flex布局 */}
      {/* 新增导航栏 */}
      <div className="w-96 flex flex-col border-r border-sky-400/30 bg-gradient-to-b from-gray-800/70 to-gray-900/70 shadow-[0_0_30px_rgba(14,165,235,0.1)]">
        {/* 头像区域 */}
        <div className="p-4 border-b border-sky-400/20 hover:bg-gray-700/30 transition-colors cursor-pointer"
          onClick={() => {/* 基本信息设置逻辑 */ }}>
          <div className="w-16 h-16 mx-auto rounded-full bg-gradient-to-r from-sky-400 to-cyan-500 shadow-lg cursor-pointer overflow-hidden">
            {/* 替换为实际头像 */}
            <div className="w-full h-full bg-gray-700" />
          </div>
        </div>

        {/* 导航菜单 */}
        <div className="flex-1 space-y-2 p-4">
          {[1, 2, 3].map((item) => (
            <div
              key={item}
              className="px-4 py-3 rounded-lg text-sky-300/90 hover:text-cyan-400 
                         bg-gray-700/30 hover:bg-gray-700/50 cursor-pointer transition-all
                         hover:shadow-[0_0_10px_rgba(14,165,235,0.3)] border border-sky-400/20"
            >
              导航栏 {item}
            </div>
          ))}
        </div>
      </div>

      {/* 原有内容容器 */}
      <div className="flex-1 flex flex-col">
        {/* 头部科技感改造 */}
        <div className="bg-gradient-to-r from-sky-500 to-cyan-600 mx-auto px-4 w-full max-w-3xl rounded-b-xl shadow-lg shadow-cyan-500/20">
          <h1 className="text-center text-2xl md:text-3xl font-bold p-4 md:p-6 bg-gradient-to-r from-sky-400 to-cyan-400 bg-clip-text text-transparent">
            TodoList
          </h1>
        </div>

        {/* 表单容器暗黑改造 */}
        <div className="relative mt-4 md:mt-6 mx-auto px-4 w-full max-w-3xl bg-gray-800 rounded-xl shadow-[0_0_30px_rgba(14,165,235,0.2)] border border-sky-400/50 py-6">
          <Form
            form={form}
            onFinish={(e) => {
              setLoading(true)
              setTimeout(() => {
                setStatus("已提交")
                setLoading(false)
              }, 1000)
              console.log(e)
            }}
            layout="vertical"
            className="space-y-6 px-4"
          >
            <Form.Item
              label="代办事项："
              name="todo"
              className="font-bold text-lg text-sky-200"  // 修改文字颜色
              labelCol={{ style: { color: '#bae6fd' } }}  // 新增亮色
            >
              <Input
                placeholder="请输入代办事项"
                size="large"
                className="w-full bg-gray-700/50 border-sky-400 hover:border-sky-300 focus:border-sky-500 text-gray-100 placeholder-gray-400"  // 暗黑风格
              />
            </Form.Item>

            <Form.Item
              label="状态："
              name="status"
              labelCol={{ style: { color: '#bae6fd' } }}
              className="font-bold text-lg text-sky-200"
            >
              <Select
                placeholder="请选择状态"
                size="large"
                className="w-full [&>.ant-select-selector]:bg-gray-700/50 [&>.ant-select-selector]:border-sky-400 [&>.ant-select-selection-item]:text-gray-100"
                dropdownClassName="bg-gray-700 [&>.ant-select-item-option-active]:bg-gray-600"
                options={[
                  {
                    value: "优先",
                    label: "优先",
                  },
                  {
                    value: "一般",
                    label: "一般",
                  },
                ]}
                onChange={(e) => { console.log(e) }}
              >
              </Select>
            </Form.Item>
            {/* 按钮组响应式优化 */}
            <div className="flex flex-col md:flex-row gap-3 md:gap-4 justify-center">
              <Button
                type="primary"
                htmlType="submit"
                className="h-10 px-6 text-lg w-full md:w-auto 
                        bg-gradient-to-r from-sky-400 to-cyan-400 hover:from-sky-500 hover:to-cyan-500 shadow-lg shadow-sky-500/20"
                disabled={status === "已提交"}
                loading={loading}
              >
                {status === "未提交" ? "提交" : "已提交"}
              </Button>
              <Button
                type="default"
                className="h-10 px-6 text-lg w-full md:w-auto
                        border-sky-400 text-sky-400 hover:border-cyan-400 hover:text-cyan-400"
                onClick={() => handleReset()}
              >
                重置
              </Button>
            </div>
          </Form>
        </div>
      </div>
    </div>
  )
}

export default App
