import React from 'react';
import { Card, Row, Col, Spin } from 'antd';
import ReactECharts from 'echarts-for-react';

// 在顶部import区域添加类型引用
import type { EChartsOption } from 'echarts';

const Dashboard = () => {
  // 模拟静态数据结构
  const mockChartData = {
    // API标记处：需要从/getChartData接口获取
    xAxis: ['周一', '周二', '周三', '周四', '周五'],
    series: [120, 200, 150, 80, 70] // 示例数据
  };

  // 修复类型定义：添加类型断言和正确配置格式
  const chartOption: EChartsOption = {
    grid: { top: 20, right: 40, left: 40, bottom: 20 },
    xAxis: {
      type: 'category',
      data: mockChartData.xAxis,
      axisLine: { lineStyle: { color: '#1890ff' } }
    },
    yAxis: { type: 'value' },
    series: [{
      data: mockChartData.series,
      type: 'line',
      smooth: true,
      areaStyle: { color: '#1890ff22' },
      lineStyle: { 
        color: '#1890ff', 
        width: 2 
      },
      // 添加必要字段
      name: '数据趋势',
      symbol: 'none' // 移除数据点标记
    }]
  } as EChartsOption;

  return (
    <Row gutter={16} style={{ padding: 24 }}>
      {/* 数据趋势模块 */}
      <Col span={16}>
        <Card title="数据趋势分析" bordered={false}>
          <ReactECharts
            option={chartOption}
            style={{ height: 400 }}
            showLoading={true}
          />
          {/* API标记处：实际使用时应替换为：
            <ReactECharts 
              option={chartData} 
              loading={isLoading}
            /> */}
        </Card>
      </Col>

      {/* 数据表格模块 */}
      <Col span={8}>
        <Card title="最新记录" bordered={false}>
          <Spin spinning={false} /* API标记处：设置loading状态 */>
            <table className="mock-table">
              <thead>
                <tr>
                  <th>ID</th>
                  <th>名称</th>
                  <th>状态</th>
                </tr>
              </thead>
              <tbody>
                {/* API标记处：需要从/getRecords接口获取 */}
                <tr>
                  <td colSpan={3} style={{ textAlign: 'center' }}>
                    数据加载中...
                  </td>
                </tr>
              </tbody>
            </table>
          </Spin>
        </Card>
      </Col>
    </Row>
  );
};

// 简易表格样式
const mockTableStyle = `
.mock-table {
  width: 100%;
  border-collapse: collapse;
  margin-top: 12px;
}
.mock-table th {
  background: #fafafa;
  padding: 8px;
  text-align: left;
}
.mock-table td {
  padding: 8px;
  border-bottom: 1px solid #f0f0f0;
}
`;

export default Dashboard;